#PySciTrivia 0.02
#Copyright (C) 2005, 2006 Michael Atkinson

#This file is part of PySciTrivia.

#PySciTrivia is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

#PySciTrivia is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with PySciTrivia; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os, sys, pygame, random, math
from pygame.locals import *

sys.path.append('modules')

from scale import windowset
from menu import LoopMenu

pygame.init()

window = windowset
pygame.display.set_caption('PySciTrivia 0.02') 

#special surface that represents the screen user actually sees
screen = pygame.display.get_surface()

#background surface
background = pygame.Surface(screen.get_size())

#start the menu
LoopMenu(screen, background)